@@ -1,4 +1,4 @@
-// In your own Cargo.toml, add the `tokio` dependency.
+// In your own Cargo.toml, add the `tokio` and `reqwest` dependencies.
 // See this crate's Cargo.toml for the versions of these dependencies which
 // are currently used in `raystack`.
 
@@ -7,18 +7,16 @@ use std::error::Error;
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn Error>> {
     use raystack::eval::eval;
-    use raystack::{ClientSeed, ValueExt};
+    use raystack::ValueExt;
+    use reqwest::Client;
 
-    let timeout_in_seconds = 30;
-
-    // If you are running `eval` many times, reuse the same `ClientSeed`
-    // each time you run the `eval` function:
-    let client_seed = ClientSeed::new(timeout_in_seconds)?;
+    // If you are running `eval` many times, reuse the same `reqwest::Client`
+    // each time you run the `eval` function.
+    let client = Client::new();
 
     let url = "http://test.com/api/bigProject/";
     let output =
-        eval(&client_seed, url, "name", "p4ssw0rd", "readAll(site)", None)
-            .await?;
+        eval(&client, url, "name", "p4ssw0rd", "readAll(site)", None).await?;
     let sites_grid = output.into_grid();
 
     // Print the raw JSON:
